From: "Jan Beulich" <JBeulich@suse.com>
To: "Kevin Cernekee" <cernekee@gmail.com>,
"Rusty Russell" <rusty@rustcorp.com.au>
Cc: <linux-kbuild@vger.kernel.org>, <linux-kernel@vger.kernel.org>
Subject: Re: [PATCH V2 2/2] module: Fix performance regression on modules with large symbol tables
Date: Mon, 21 Nov 2011 08:08:28 +0000 [thread overview]
Message-ID: <4ECA150C0200007800062072@nat28.tlf.novell.com> (raw)
In-Reply-To: <87ipme9i9o.fsf@rustcorp.com.au>
>>> On 21.11.11 at 06:06, Rusty Russell <rusty@rustcorp.com.au> wrote:
> On Thu, 17 Nov 2011 19:15:02 -0800, Kevin Cernekee <cernekee@gmail.com> wrote:
>> Potential memory savings from reusing EXACT strtab matches: 36,475 bytes
>> total; 35,432 from nvidia.ko. For comparison, discarding non-core
>> strtab entries saved about 91KB on my system.
> ...
>> Original scheme: 1.230s
>> With patch V2: 0.280s
>> With naive copying: 0.058s
>
> I'm deeply tempted. It's very simple, 46 lines shorter, preserves exact
> matches, and doesn't have any strange slowdowns on corner cases.
>
> But like Kevin, I could be convinced either way. Jan?
I'd be fine with the simpler solution, as long it is clearly understood
(and marked as intended to be that was for the time being) that it
has room for improvement, should it ever turn out to yield more
significant savings in other contexts.
Jan
prev parent reply other threads:[~2011-11-21 8:08 UTC|newest]
Thread overview: 10+ messages / expand[flat|nested] mbox.gz Atom feed top
2011-11-13 3:08 [PATCH V2 1/2] module: Add comments describing how the "strmap" logic works Kevin Cernekee
2011-11-13 3:08 ` [PATCH V2 2/2] module: Fix performance regression on modules with large symbol tables Kevin Cernekee
2011-11-14 0:35 ` Rusty Russell
2011-11-14 8:48 ` Jan Beulich
2011-11-16 0:24 ` Rusty Russell
2011-11-18 3:15 ` Kevin Cernekee
2011-11-21 5:06 ` Rusty Russell
2011-11-21 6:29 ` Kevin Cernekee
2011-11-21 23:57 ` Rusty Russell
2011-11-21 8:08 ` Jan Beulich [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4ECA150C0200007800062072@nat28.tlf.novell.com \
--to=jbeulich@suse.com \
--cc=cernekee@gmail.com \
--cc=linux-kbuild@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=rusty@rustcorp.com.au \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®